@@ -17,6 +17,7 @@ ui <- tagList(
                                                 "Single Sample Processing" = "single"),
                                     selected = "batch"),
                                    style = "margin: 20px 0px 0px 0px"),
+                          fluidRow(column(4, textOutput("messageanalysis"), style="color:red")),
                           fluidRow(radioButtons("sI_polarity", "Polarity",
                                                        choices = c("Positive" = "positive",
                                                                    "Negative" = "negative"),
@@ -36,6 +37,21 @@ ui <- tagList(
                                        "acquisitionmode (MS, DIA or DDA) and\n",
                                        "sampletype (QC, group1, group2, etc.)"), style = "color:grey"),
                                  style = "margin: 20px 0px 0px 0px"),
+                          fluidRow(fileInput("metadata", "Metadata csv file",
+                                             multiple = FALSE,
+                                             accept = c("text/plain",
+                                                        ".csv")),
+                                   h6(em("It must be a csv file with 3 columns:\n",
+                                         "sample (mzXML file names),\n",
+                                         "acquisitionmode (MS, DIA or DDA) and\n",
+                                         "sampletype (QC, group1, group2, etc.)"), style = "color:grey"),
+                                   style = "margin: 20px 0px 0px 0px"),
+                          fluidRow(column(4, h5(strong("sep")),
+                                          h6(em("column delimiter."), style = "color:grey")),
+                                   column(3, textInput("sep1", "", value=","))),
+                          fluidRow(column(4, h5(strong("dec")),
+                                          h6(em("decimal character."), style = "color:grey")),
+                                   column(3, textInput("dec1", "", value="."))),
                           tags$hr(style = "border-color: white"),
                           fluidRow(actionButton("JumpTo2", "Next >", width = "100px"),
                                    style = "margin: 20px 0px 0px 0px")
@@ -150,7 +166,7 @@ ui <- tagList(
                                                       selected = FALSE))),
                        fluidRow(column(6, h5(strong("ncores")),
                                        h6(em("number of cores to be used in case parallel is TRUE. 2 by default."), style = "color:grey")),
-                                column(3, numericInput("ncore", "", value = 2, min = 0, max = 50, step = 1))),
+                                column(3, numericInput("ncores", "", value = 2, min = 0, max = 50, step = 1))),
                        tags$hr(),
                        fluidRow(actionButton("GoBackTo2", "< Previous", width = "100px", 
                                              style="margin:40px 0px"), 
@@ -184,7 +200,6 @@ ui <- tagList(
                                                                "PEo" = "PEo",
                                                                "PEp" = "PEp",
                                                                "PG" = "PG",
-                                                               "PI" = "PI",
                                                                "Sphingoid bases" = "Sph",
                                                                "Sphingoid bases phosphate" = "SphP",
                                                                "Cer" = "Cer",
@@ -195,9 +210,9 @@ ui <- tagList(
                                                                "CE" = "CE",
                                                                "DG" = "DG",
                                                                "TG" = "TG"),
-                                                             selected = c("MG", "LPC", "LPE", "PC", "PCo", "PCp", "PE", "PEo", "PEp", "PG", "PI", "Sph",
+                                                             selected = c("MG", "LPC", "LPE", "PC", "PCo", "PCp", "PE", "PEo", "PEp", "PG", "Sph",
                                                                           "SphP", "Cer", "AcylCer", "CerP", "SM", "Carnitines", "CE", "DG", "TG"))),
-                                column(6, checkboxGroupInput("lipidClassesNeg", "Lipid classes to annotate for ESI- :",
+                                column(6, checkboxGroupInput("lipidClassesNeg", "Lipid classes to annotate for ESI+ :",
                                                              c("FA" = "FA",
                                                                "FAHFA" = "FAHFA",
                                                                "LPC" = "LPC",
@@ -219,12 +234,11 @@ ui <- tagList(
                                                                "Cer" = "Cer",
                                                                "AcylCer" = "AcylCer",
                                                                "CerP" = "CerP",
-                                                               "SM" = "SM",
                                                                "CL" = "CL",
                                                                "Bile Acids" = "BA"),
                                                              selected = c("FA", "FAHFA", "LPC", "LPE", "LPG", "LPI", "LPS", 
                                                                           "PC", "PCo", "PCp", "PE", "PEo", "PEp", "PG", "PI", "PS", 
-                                                                          "Sph", "SphP", "Cer", "AcylCer", "CerP", "SM", "CL", "BA")))),
+                                                                          "Sph", "SphP", "Cer", "AcylCer", "CerP", "CL", "BA")))),
                        tags$hr(),
                        fluidRow(actionButton("GoBackTo3", "< Previous", width = "100px", 
                                              style="margin:40px 0px"), 
